/****************************************************************************/
/*                                                                          */
/*  Project:    ADI_SDP                                                     */
/*  Design:     SDP1                                                        */
/*  Modules:    SPI 0 using 3 chip selects, SDP pins 82-85, 37, 38          */
/*              SPI 1 using 1 chip select, SDP pins 87-92 (SPORT)           */
/*              GPIO                                                        */
/*  Variant:    for BeMicro 2                                               */
/*  Author:     Harald Fluegel                                              */
/*                                                                          */
/****************************************************************************/

module fpga
    (
    input           ext_clk,        // external clock, 50 MHz
    output  [7:0]   led,            // 8 single LEDs
    output          epcs_dclk,      // EPCS device
    output          epcs_asdi,
    output          epcs_cs_n,
    input           epcs_data,
    input           exp_pres,       // expansion board is present
    input           exp_rst_n,      // reset switch on expansion board

                // bemicro signal       SDP pin, signal
    input           p1,             //  99, par_int
    input           p2,             //  83, spi_miso
    input           p3,             // 107 + 91, par_d10 + sport_dr0
    inout           p4,             // 106 + 92, par_d8 + sport_rsclk
    inout           p5,             // 105, par_d6
    inout           p6,             // 103, par_d4
    inout           p7,             // 102, par_d2
    inout           p8,             // 101, par_d0
    inout           p9,             // 100, par_wr
    inout           p10,            // 110 + 89, par_d15 + sport_tfs
    inout           p11,            //  97, par_a2
    inout           p12,            //  96, par_a0
    inout           p13,            //  78, gpio1
    inout           p14,            //  94, par_clk
    inout           p15,            //  85, spi_sel_a
    inout           p16,            //  84, spi_mosi
    inout           p17,            //  82, spi_clk
    inout           p18,            // 108 + 90, par_d12 + sport_rfs
    inout           p19,            //  77, gpio3
    inout           p20,            //  79, scl_0
    inout           p21,            //  95, par_fs2
    inout           p22,            //  80, sda_0
    inout           p23,            //  76, gpio5
    inout           p24,            //  74, gpio7
    inout           p25,            //  73, tmr_b
    inout           p26,            //  72, tmr_d
    inout           p27,            //  43, gpio0
    inout           p28,            //  62, uart_tx
    inout           p29,            //  13 + 87, par_d13 + sport_tsclk
    input           p35,            //  35, sport_int
    input           p36,            //  59, uart_rx
    inout           p37,            //  47, gpio6
    inout           p38,            //  15 + 31, par_d9 + sport_dr1
    inout           p39,            //  16, par_d7
    inout           p40,            //  18, par_d5
    inout           p41,            //  19, par_d3
    inout           p42,            //  20, par_d1,
    inout           p43,            //  21, par_rd
    inout           p44,            //  22, par_cs
    inout           p45,            //  48, tmr_a
    inout           p46,            //  25, par_a1
    inout           p47,            //  26, par_fs3
    inout           p48,            //  27, par_fs1
    inout           p49,            //  12 + 88, par_d14 + sport_dt0
    inout           p50,            //  37, spi_sel_b
    inout           p51,            //  38, spi_sel_c
    inout           p52,            //  41, sda_1
    inout           p53,            //  42, scl_1
    inout           p54,            //  71, n/c
    inout           p55,            //  44, gpio2
    inout           p56,            //  45, gpio4
    inout           p57,            //  14 + 32, par_d11 + sport_dt1
    inout           p58,            //  24, par_a3
    inout           p59,            //  49, tmr_c,
    
    output          p60             //  reset request, driving U2.2 on interposer board
    );

//----------------------------------------------------------------------
// local wires
//----------------------------------------------------------------------

wire    [18:0]  addr;               // byte address
wire    [1:0]   ram_be_n;           // byte enable bus
wire    [7:0]   led_port;           // high-active signals

wire    [7:0]   ctrl;               // global control

//----------------------------------------------------------------------
// SOPC system 
//----------------------------------------------------------------------

uC uC1
    (
    .ext_clk(ext_clk),
    .reset_n(1'b1),
    .sys_clk(),
    .locked_from_the_main_pll(),
    .phasedone_from_the_main_pll(),
    .dclk_from_the_epcs_flash_controller(epcs_dclk),
    .sce_from_the_epcs_flash_controller(epcs_cs_n),
    .sdo_from_the_epcs_flash_controller(epcs_asdi),
    .data0_to_the_epcs_flash_controller(epcs_data),
    .out_port_from_the_led(led_port),
    .out_port_from_the_ctrl(ctrl),
	 
    .bidir_port_to_and_from_the_gpio({p24, p37, p23, p56, p19, p55, p13, p27}),
	 
	 .ad7176_2_0_cnv_o  (p15),
    .ad7176_2_0_sdi      (p16),
	 .ad7176_2_0_sdo      (p2),
	 .ad7176_2_0_sclk_o       (p17)
    );

assign led      = ~led_port;    // inverted since LED shine when output is low
assign p60      = 1'b1;         // reset request not needed

endmodule
